"""Escalation channel implementations.

Authors:
    Vio Albert Ferdinand (vio.a.ferdinand@gdplabs.id)

References:
    NONE
"""

from digital_employee_core.escalation.channels.google_mail_mcp_channel import GoogleMailMCPEscalationChannel

__all__ = [
    "GoogleMailMCPEscalationChannel",
]
