"""Schedule configuration module.

Authors:
    Immanuel Rhesa (immanuel.rhesa@gdplabs.id)

References:
    NONE
"""

from digital_employee_core.schedule.schedule_config import ScheduleItemConfig

__all__ = ["ScheduleItemConfig"]
