"""Digital Employee module.

This module provides the main DigitalEmployee orchestrator class.
"""

from digital_employee_core.digital_employee.digital_employee import DigitalEmployee

__all__ = ["DigitalEmployee"]
